import asyncio
import aiohttp
from tqdm import tqdm

# List of files to exclude from download
exclude_files = [
	"Shen3_e_S85_R2_001.fastq.gz",
	"Shen3_e_S85_R1_001.fastq.gz",
	"S2_R2_S73_R2_001.fastq.gz",
	"S2_R2_S73_R1_001.fastq.gz",
	"S2_R1_S71_R2_001.fastq.gz",
	"S2_R1_S71_R1_001.fastq.gz",
	"S2_719_R2_S74_R2_001.fastq.gz",
	"S2_719_R2_S74_R1_001.fastq.gz",
	"S2_719_R1_S72_R2_001.fastq.gz",
	"S2_719_R1_S72_R1_001.fastq.gz",
	"Kra_e_S84_R2_001.fastq.gz",
	"Kra_e_S84_R1_001.fastq.gz",
	"iS2_R1_S70_R2_001.fastq.gz",
	"iS2_R1_S70_R1_001.fastq.gz",
	"ggCTCF_R3_S40_R2_001.fastq.gz",
	"ggCTCF_R3_S40_R1_001.fastq.gz",
	"CTCF_S2_R2_S67_R2_001.fastq.gz",
	"CTCF_S2_R2_S67_R1_001.fastq.gz",
	"CTCF_S2_R1_S66_R2_001.fastq.gz",
	"CTCF_S2_R1_S66_R1_001.fastq.gz",
	"CTCF_S2_719_R2_S69_R2_001.fastq.gz",
	"CTCF_S2_719_R2_S69_R1_001.fastq.gz",
	"CTCF_S2_719_R1_S68_R2_001.fastq.gz",
	"CTCF_S2_719_R1_S68_R1_001.fastq.gz",
	"zfCTCF_a_R3_S43_R2_001.fastq.gz",
	"zfCTCF_a_R3_S43_R1_001.fastq.gz",
	"zfCTCF_a_R2_S39_R2_001.fastq.gz",
	"fCTCF_a_R2_S39_R2_001.fastq.gz",
	"zfCTCF_a_R2_S39_R2_001.fastq.gz",
	"zfCTCF_a_R2_S39_R1_001.fastq.gz",
	"zfCTCF_R3_S42_R2_001.fastq.gz",
	"zfCTCF_R3_S42_R1_001.fastq.gz",
	"zfCTCF_R2_S38_R2_001.fastq.gz",
	"zfCTCF_R2_S38_R1_001.fastq.gz",
	"lsCTCF_a_R3_S55_R2_001.fastq.gz",
	"lsCTCF_a_R3_S55_R1_001.fastq.gz",
	"lsCTCF_a_R1_S45_R2_001.fastq.gz",
	"lsCTCF_a_R1_S45_R1_001.fastq.gz",
	"lsCTCF_R3_S54_R2_001.fastq.gz",
	"lsCTCF_R3_S54_R1_001.fastq.gz",
	"lsCTCF_R1_S44_R2_001.fastq.gz",
	"lsCTCF_R1_S44_R1_001.fastq.gz",
	"ggCTCF_a_R3_S41_R2_001.fastq.gz",
	"ggCTCF_a_R3_S41_R1_001.fastq.gz",
	"dmCTCF_a_R2_S47_R2_001.fastq.gz",
	"dmCTCF_a_R2_S47_R1_001.fastq.gz",
	"dmCTCF_a_R1_S51_R2_001.fastq.gz",
	"dmCTCF_a_R1_S51_R1_001.fastq.gz",
	"dmCTCF_R2_S46_R2_001.fastq.gz",
	"dmCTCF_R2_S46_R1_001.fastq.gz",
	"dmCTCF_R1_S50_R2_001.fastq.gz",
	"dmCTCF_R1_S50_R1_001.fastq.gz",
	"bskCTCF_a_R1_S49_R2_001.fastq.gz",
	"bskCTCF_a_R1_S49_R1_001.fastq.gz",
	"bskCTCF_aR2_S59_R2_001.fastq.gz",
	"bskCTCF_aR2_S59_R1_001.fastq.gz",
	"bskCTCF_R2_S58_R2_001.fastq.gz",
	"bskCTCF_R2_S58_R1_001.fastq.gz",
	"bskCTCF_R1_S48_R2_001.fastq.gz",
	"bskCTCF_R1_S48_R1_001.fastq.gz",
	"brCTCF_a_R2_S57_R2_001.fastq.gz",
	"brCTCF_a_R2_S57_R1_001.fastq.gz",
	"brCTCF_a_R1_S53_R2_001.fastq.gz",
	"brCTCF_a_R1_S53_R1_001.fastq.gz",
	"brCTCF_R2_S56_R2_001.fastq.gz",
	"brCTCF_R2_S56_R1_001.fastq.gz",
	"brCTCF_R1_S52_R2_001.fastq.gz",
	"brCTCF_R1_S52_R1_001.fastq.gz",
	"Prime_contr_S37_R2_001.fastq.gz",
	"Prime_contr_S37_R1_001.fastq.gz"
]

# Public link to the folder
public_key = "https://disk.yandex.ru/d/8UsiatSg9zTubQ"

# Function to get direct download link for a file
async def get_download_link(session, file_path):
    base_url = "https://cloud-api.yandex.net/v1/disk/public/resources/download"
    params = {'public_key': public_key, 'path': file_path}
    async with session.get(base_url, params=params) as response:
        if response.status == 200:
            data = await response.json()
            return data['href']
        else:
            print(f"Error getting download link for file {file_path}: {response.status}")
            return None

async def download_file(session, file_path):
    download_link = await get_download_link(session, file_path)
    if download_link:
        async with session.get(download_link) as response:
            if response.status == 200:
                file_name = file_path.split('/')[-1]
                with open(file_name, 'wb') as f, tqdm(desc=file_name) as pbar:
                    while True:
                        chunk = await response.content.read(1024)
                        if not chunk:
                            break
                        f.write(chunk)
                        pbar.update(len(chunk))
                print(f"File {file_name} downloaded successfully")
            else:
                print(f"Error downloading file {file_path}: {response.status}")
    else:
        print(f"Unable to get download link for file {file_path}")

async def main():
    async with aiohttp.ClientSession() as session:
        tasks = []
        offset = 0
        while True:
            response = await session.get(f"https://cloud-api.yandex.net/v1/disk/public/resources?public_key={public_key}&limit=100&offset={offset}")
            data = await response.json()
            items = data['_embedded']['items']
            if not items:
                break
            for item in items:
                file_path = item['path']
                if file_path.split('/')[-1] not in exclude_files:
                    tasks.append(download_file(session, file_path))
            offset += 100
        await asyncio.gather(*tasks)

# Run the event loop
if __name__ == "__main__":
    asyncio.run(main())
